pub struct ConvergenceDegree {
pub result: Vec<f64>,
pub ins: Vec<f64>,
pub outs: Vec<f64>,
}Expand description
Convergence degrees of the edges, see
convergence_degree.
Fields
result: Vec<f64>The convergence degree of each edge, in (-1, 1).
ins: Vec<f64>The size of the input set of each edge.
outs: Vec<f64>The size of the output set of each edge.