EigenScores

Struct EigenScores 

pub struct EigenScores {
    pub scores: Vec<f64>,
    pub value: f64,
}
Vertex scores that are an eigenvector, with the corresponding eigenvalue.

Returned by pagerank and its personalized variants, and by eigenvector_centrality.

Fields

scores: Vec<f64>

The score of each vertex (for PageRank: of each requested vertex).

value: f64

The eigenvalue. For PageRank it is always 1.0 with PRPACK and should be very close to one with ARPACK. For eigenvector centrality it is the leading eigenvalue of the adjacency matrix (zero for acyclic graphs, where the measure is not meaningful).