pub struct EigenvectorCentralization {
pub scores: Vec<f64>,
pub value: f64,
pub centralization: f64,
pub theoretical_max: f64,
}Expand description
Eigenvector centralities together with the graph-level centralization
index, see centralization_eigenvector_centrality.
Fields
scores: Vec<f64>The eigenvector centrality of all vertices, scaled so that the maximum is 1.
value: f64The leading eigenvalue.
centralization: f64The graph-level centralization index (normalized if requested).
theoretical_max: f64The centralization of the most centralized graph with the same number of vertices (and directedness).