pub struct HubAuthority {
pub hubs: Vec<f64>,
pub authorities: Vec<f64>,
pub value: f64,
}Expand description
Kleinberg’s hub and authority scores, see
hub_and_authority_scores.
Fields
hubs: Vec<f64>Hub score of each vertex, scaled so that the maximum is 1.
Authority score of each vertex, scaled so that the maximum is 1.
value: f64The leading eigenvalue of A Aᵀ (equivalently, of Aᵀ A).